poets — poets 0.3.2 documentation

# poets

This is the documentation of poets, a package with aims to provide a standard library that can be used for collecting and resampling geospatial image datasets.

## Contents

- Introduction to poets, the Python Open Earth Observation Tools
  - Features
  - Supported Data
    - Supported Data Sources
    - Supported File Types
  - Installation
    - Prerequisites
    - How to install python packages
    - Linux
  - Contribute
  - Ancillary data
- Examples
  - Some notes before we start
  - Setting up a Poet base class
  - Usage of custom shapefiles
  - Adding a source
  - Download and resample data
    - Download and resample data from sources individually
    - Download only
    - Resampling only
  - Reading and plotting images
  - Reading and plotting time series
  - Web Interface
    - Using colorbars and units
    - Scaling data
  - Complete Example
- License
- Module Reference
  - poets package
    - Subpackages
    - Submodules
    - poets.poet module
    - Module contents

## Indices and tables

- Index
- Module Index
- Search Page